@@ -48,12 +48,12 @@ SEXP processx_exec(SEXP command, SEXP args,
 		   SEXP windows_verbatim_args,
 		   SEXP windows_hide_window, SEXP private_, SEXP cleanup,
 		   SEXP wd, SEXP encoding, SEXP tree_id);
-SEXP processx_wait(SEXP status, SEXP timeout);
-SEXP processx_is_alive(SEXP status);
-SEXP processx_get_exit_status(SEXP status);
-SEXP processx_signal(SEXP status, SEXP signal);
-SEXP processx_interrupt(SEXP status);
-SEXP processx_kill(SEXP status, SEXP grace);
+SEXP processx_wait(SEXP status, SEXP timeout, SEXP name);
+SEXP processx_is_alive(SEXP status, SEXP name);
+SEXP processx_get_exit_status(SEXP status, SEXP name);
+SEXP processx_signal(SEXP status, SEXP signal, SEXP name);
+SEXP processx_interrupt(SEXP status, SEXP name);
+SEXP processx_kill(SEXP status, SEXP grace, SEXP name);
 SEXP processx_get_pid(SEXP status);
 SEXP processx_create_time(SEXP r_pid);
 
